﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace RSPhotography.DataAccess
{
    public class CatalogDataAccessor : DataAccessor
    {
        public ReadOnlyCollection<Catalog> GetAllItems()
        {
            return _context.Catalogs.ToList().AsReadOnly();
        }

public ReadOnlyCollection<Catalog> FindItemsByLocation(Location loc)
{
    if (loc.LocationId <= 0 || loc.RegionId <= 0)
    {
        throw new ArgumentException("The Location's LocationId or RegionId must be specified");
    }

    _context.Configuration.LazyLoadingEnabled = false;
    _context.Configuration.ProxyCreationEnabled = false;

IQueryable<Catalog> query = (from a in _context.Catalogs
                                    .Include("Locations")
                                    .Include("Genres")
                                    .Include("Sizes")
                                select a);
    if (loc.LocationId > 0)
    {
        query = query.Where(x => x.Locations.Any(y => y.LocationId == loc.LocationId));
    }
    if (loc.RegionId > 0)
    {
        query = query.Where(x => x.Locations.Any(y => y.RegionId == loc.RegionId));
    }

    return query.ToList().AsReadOnly();
}
    }
}
